ComparedFace class

Represents a reference information of the compared face.

Properties

face → MatchFacesDetectionFace?
The face detection result.
no setter
faceIndex → int?
The index to the array of faces in the detection results.
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → MatchFacesImage
The input image used for comparison operation.
no setter
imageIndex → int
The index to the input image in the input array provided to the request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ComparedFace?