ComparedFacesPair class

Represents a result of the ComparedFace attempt to compare input images.

Properties

error → MatchFacesException?
The error describes a failed pair comparison and contains MatchFacesErrorCode codes.
no setter
first → ComparedFace
The first face in the comparison pair.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score → double?
The raw value returned by the service without applying any thresholds or comparison rules. The value shows the degree of similarity of compared faces, the lower - the more similar, and vice versa less similar. The score is used in conjunction with the input image imageType to evaluate similarity.
no setter
second → ComparedFace
The second face in the comparison pair.
no setter
similarity → double
Similarity of the faces pair. Floating point value from 0 to 1.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ComparedFacesPair?