DetectFacesRequest class

Detect Faces Request. Could be created by predefined scenarios (e.g: DetectFacesRequest.qualityICAO, DetectFacesRequest.cropAllFaces etc. ) or by using custom DetectFacesConfig.

Constructors

DetectFacesRequest(Uint8List image, DetectFacesConfig config, {String? tag})
Create DetectFacesRequest object.
DetectFacesRequest.allAttributes(Uint8List image)
Creates a request for all available attribute results.
DetectFacesRequest.cropAllFaces(Uint8List image)
Creates a request for cropped portraits of all the people in the image.
DetectFacesRequest.cropCentralFace(Uint8List image)
Creates a request for a cropped portrait of the person whose face is the most central.
DetectFacesRequest.qualityFull(Uint8List image)
Creates a request to check all the available quality characteristics.
DetectFacesRequest.qualityICAO(Uint8List image)
Creates a request to check the quality characteristics based on the ICAO standard.
DetectFacesRequest.qualityVisaSchengen(Uint8List image)
Creates a request to check the quality characteristics based on the Schengen visa standard.
DetectFacesRequest.qualityVisaUSA(Uint8List image)
Creates a request to check the quality characteristics based on the USA visa standard.
DetectFacesRequest.thumbnail(Uint8List image)
Creates a request for a cropped portrait of the person whose face is the most central in the image in the original size.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → DetectFacesRequest?