EnrollmentRequest class
Constructors
- EnrollmentRequest.withImage(String externalId, Uint8List trustedImage, {String? groupId})
- EnrollmentRequest.withImageUrl(String externalId, String trustedImageUrl, {String? groupId})
Properties
- externalId → String
-
no setter
- groupId → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trustedImage → Uint8List?
-
no setter
- trustedImageUrl → String?
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic jsonObject) → EnrollmentRequest?