FaceCaptureConfig class

Constructors

FaceCaptureConfig({bool copyright = true, bool cameraSwitchEnabled = false, bool closeButtonEnabled = true, bool torchButtonEnabled = true, bool vibrateOnSteps = true, bool detectOcclusion = true, bool showFaceAnimation = true, bool preventScreenRecording = false, int? cameraPositionAndroid, CameraPosition cameraPositionIOS = CameraPosition.FRONT, List<ScreenOrientation> screenOrientation = const [ScreenOrientation.PORTRAIT], double? timeout, double? holdStillDuration})

Properties

cameraPositionAndroid ↔ int?
Android only.
getter/setter pair
cameraPositionIOS ↔ CameraPosition
IOS only.
getter/setter pair
cameraSwitchEnabled ↔ bool
getter/setter pair
closeButtonEnabled ↔ bool
getter/setter pair
getter/setter pair
detectOcclusion ↔ bool
Enables 'remove occlusion' animation & hint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
holdStillDuration ↔ double?
getter/setter pair
preventScreenRecording ↔ bool
Prevents screenshots and screen recording while FaceCapture camera screen is displayed. Defaults to false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenOrientation ↔ List<ScreenOrientation>
Allows you to specify an orientation of the camera view controller.
getter/setter pair
showFaceAnimation ↔ bool
Enables global face hint animation.
getter/setter pair
timeout ↔ double?
getter/setter pair
torchButtonEnabled ↔ bool
getter/setter pair
vibrateOnSteps ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → FaceCaptureConfig?