FaceSDK class

Constructors

FaceSDK()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getFaceSdkVersion() → Future
getServiceUrl() → Future
matchFaces(dynamic request) → Future
matchFacesSimilarityThresholdSplit(dynamic faces, dynamic similarity) → Future
matchFacesWithConfig(dynamic request, dynamic config) → Future
presentFaceCaptureActivity() → Future
presentFaceCaptureActivityWithConfig(dynamic config) → Future
setLanguage(dynamic language) → Future
setServiceUrl(dynamic url) → Future
startLiveness() → Future
startLivenessWithConfig(dynamic config) → Future
stopFaceCaptureActivity() → Future
stopLivenessProcessing() → Future