ImageQualityRange class

Base range value for Image Quality parameters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
max → double
Maximum range value.
no setter
min → double
Minimum range value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageQualityRange?