ImageQualityResult class

Quality assessment result.

Properties

group → ImageQualityGroupName
Image quality characteristic group.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → ImageQualityCharacteristicName
The name of the characteristic.
no setter
range → ImageQualityRange
The range of set values for this characteristic.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ImageQualityResultStatus
The assessment status of the characteristic.
no setter
value → double
The assessed value for the characteristic.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → ImageQualityResult?