MatchFacesConfig class

Constructors

MatchFacesConfig({ProcessingMode processingMode = ProcessingMode.ONLINE, bool locationTrackingEnabled = true})

Properties

hashCode → int
The hash code for this object.
no setterinherited
locationTrackingEnabled ↔ bool
getter/setter pair
processingMode ↔ ProcessingMode
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesConfig?