MatchFacesDetection class

Represents detection results on an input image as a part of MatchFacesResponse.

Properties

error → MatchFacesException?
The error describes a failed face detection and contains MatchFacesErrorCode codes.
no setter
faces → List<MatchFacesDetectionFace>
The array of faces detected on the image.
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → MatchFacesImage
The input image used for comparison operation.
no setter
imageIndex → int
The index to the input image in the input array provided to the request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesDetection?