MatchFacesDetectionFace class

Represents face detection information as a part of MatchFacesResponse.

Properties

crop → Uint8List?
Base64 image of the aligned and cropped portrait. Returned if MatchFacesRequest.outputImageParams is set or predefined scenario is used.
no setter
faceIndex → int
The index of the face detection object in the array of detections.
no setter
faceRect → Rect
Rectangular area of the detected face in the original image.
no setter
hashCode → int
The hash code for this object.
no setterinherited
landmarks → List<Point>
Main coordinates of the detected face (eyes, nose, lips, ears and etc.).
no setter
originalRect → Rect?
Coordinates of the rectangle with the face on the original image prepared for the face crop. Requires OutputImageCrop.returnOriginalRect is set. Returns null if OutputImageCrop.returnOriginalRect isn't set.
no setter
rotationAngle → double?
Rotation is measured counterclockwise in degrees, with zero indicating that a line drawn between the eyes is horizontal relative to the image orientation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesDetectionFace?