MatchFacesImage class

Constructors

MatchFacesImage()

Properties

bitmap ↔ String?
getter/setter pair
detectAll ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ String?
getter/setter pair
imageType ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesImage?