MatchFacesRequest class

Constructors

MatchFacesRequest()

Properties

customMetadata ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
images ↔ List<MatchFacesImage?>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnails ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesRequest?