MatchFacesResponse class

The response from the MatchFacesRequest.

Properties

detections → List<MatchFacesDetection>
Face detection results for each given image.
no setter
error → MatchFacesException?
The error describes a failed match faces request and contains MatchFacesErrorCode codes.
no setter
hashCode → int
The hash code for this object.
no setterinherited
results → List<ComparedFacesPair>
Face comparison results with score and similarity values.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesResponse?