OutputImageParams class

Set of parameter for image processing.

Constructors

OutputImageParams({OutputImageCrop? crop, Color? backgroundColor})

Properties

backgroundColor → Color?
If set, the background color is replaced. The silhouette of a person is cut out and the background is filled with this color.
no setter
crop → OutputImageCrop?
If set, the Base64 of an aligned and cropped portrait is returned in the crop field. Alignment is performed according to type. If a head on the original image is tilted, for the returned portrait it is aligned in a straight vertical line.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → OutputImageParams?