Person class

A Person Database object that represents Person.

Implementers

Constructors

Person()

Properties

createdAt DateTime?
no setter
expireAt DateTime?
getter/setter pair
externalId String?
getter/setter pair
groups List<String>?
Array if Group IDs Person belongs to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
metadata ↔ dynamic
A free-form object containing Person extended attributes. Updatable field.
getter/setter pair
name String?
Person name. Updatable field.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl int?
getter/setter pair
updatedAt DateTime?
Person update date.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) Person?