PersonGroup class

Person Database object that represents Group of Person.

Properties

createdAt → DateTime
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setter
metadata ↔ dynamic
A free-form object containing Group extended attributes. Updatable field.
getter/setter pair
name ↔ String
PersonGroup name. Updatable field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → PersonGroup?