SearchPerson class

A Person Database object that represents th result of Person search.

Inheritance

Properties

createdAt → DateTime?
no setterinherited
detection → SearchPersonDetection?
Detection data relative to the search input image.
no setter
expireAt ↔ DateTime?
getter/setter pairinherited
externalId ↔ String?
getter/setter pairinherited
groups ↔ List<String>?
Array if Group IDs Person belongs to.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pairinherited
images → List<SearchPersonImage>
Array of images where the Person is found.
no setter
metadata ↔ dynamic
A free-form object containing Person extended attributes. Updatable field.
getter/setter pairinherited
name ↔ String?
Person name. Updatable field.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ int?
getter/setter pairinherited
updatedAt ↔ DateTime?
Person update date.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic>? jsonObject) → SearchPerson?
override