SearchPersonImage class

A Person Database object that represents Image result of Person Search.

Inheritance

Properties

contentType → String?
no setterinherited
createdAt → DateTime
no setterinherited
distance → double
The similarity distance score. The lower the distance, the higher the face's similarity. From 0.0 to 2.0.
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
no setterinherited
metadata → dynamic
no setterinherited
path → String
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
similarity → double
The similarity score. From 0.0 to 1.0.
no setter
url → String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SearchPersonImage?
override