SearchPersonRequest class

Request object that configures Search settings.

Constructors

SearchPersonRequest(ImageUpload image, {List<String>? groupIdsForSearch, double? threshold, int? limit, String? tag, bool detectAll = false, OutputImageParams? outputImageParams})
Create SearchPersonRequest object.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → SearchPersonRequest?