LivenessErrorCode enum
Values
- NOT_INITIALIZED → const LivenessErrorCode
-
FaceSDK Core is not initialized.
const LivenessErrorCode(0) - NO_LICENSE → const LivenessErrorCode
-
There is no valid license on the service.
const LivenessErrorCode(1) - API_CALL_FAILED → const LivenessErrorCode
-
Liveness API call failed due to networking error or backend internal error.
const LivenessErrorCode(2) - SESSION_START_FAILED → const LivenessErrorCode
-
Failed when Core could not start new session.
const LivenessErrorCode(3) - CANCELLED → const LivenessErrorCode
-
User cancelled liveness processing.
const LivenessErrorCode(4) - PROCESSING_TIMEOUT → const LivenessErrorCode
-
Processing finished by timeout.
const LivenessErrorCode(5) - PROCESSING_FAILED → const LivenessErrorCode
-
Processing failed.
const LivenessErrorCode(6) - PROCESSING_FRAME_FAILED → const LivenessErrorCode
-
Failed when Core cannot recognize frame.
const LivenessErrorCode(7) - APPLICATION_INACTIVE → const LivenessErrorCode
-
Client application did enter the background, liveness process interrupted.
const LivenessErrorCode(8) - BAD_FACE_QUALITY → const LivenessErrorCode
-
Processing finished by bad face quality.
const LivenessErrorCode(9) - BAD_FRAME_SIZE → const LivenessErrorCode
-
Processing finished by bad frame size.
const LivenessErrorCode(10) - CAMERA_NOT_AVAILABLE → const LivenessErrorCode
-
Device has no available camera.
const LivenessErrorCode(11) - CAMERA_NO_PERMISSION → const LivenessErrorCode
-
Application does not have camera permission.
const LivenessErrorCode(12) - CONTEXT_IS_NULL → const LivenessErrorCode
-
Application context is null.
Android only.
const LivenessErrorCode(13) - IN_PROGRESS_ALREADY → const LivenessErrorCode
-
Liveness process already in progress.
Android only.
const LivenessErrorCode(14) - ZOOM_NOT_SUPPORTED → const LivenessErrorCode
-
The camera on the current device doesn't support zoom change.
Android only.
const LivenessErrorCode(15)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getByValue(
int? i) → LivenessErrorCode?
Constants
-
values
→ const List<
LivenessErrorCode> - A constant List of the values in this enum, in order of their declaration.