MatchFacesDetection class

Constructors

MatchFacesDetection()

Properties

exception ↔ MatchFacesException?
getter/setter pair
faces ↔ List<MatchFacesDetectionFace?>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ MatchFacesImage?
getter/setter pair
imageIndex ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(dynamic jsonObject) → MatchFacesDetection?