SearchPersonFilter class
Constructors
-
SearchPersonFilter({List<
String> groups = const [], double threshold = 0, int limit = 1})
Properties
- exclude → bool
-
no setter
- fieldName → String?
-
no setter
-
fieldValues
→ List<
String> ? -
no setter
-
groups
↔ List<
String> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold ↔ double
-
getter/setter pair
Methods
-
filterField(
String fieldName, List< String> fieldValues, {bool exclude = false}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic jsonObject) → SearchPersonFilter?